complete -c git-smash -n "__fish_use_subcommand" -l format -d 'Git log format to pretty print the targets' -r
complete -c git-smash -n "__fish_use_subcommand" -s n -l max-count -d 'Limit number of listed commits (0 for unlimited stream)' -r
complete -c git-smash -n "__fish_use_subcommand" -l recent -d 'List commits acquired from recent history (default 0)' -r
complete -c git-smash -n "__fish_use_subcommand" -l range -d 'Limit the listed commits to the given range' -r
complete -c git-smash -n "__fish_use_subcommand" -l list -d 'List mode to print all potential targets to stdout'
complete -c git-smash -n "__fish_use_subcommand" -l select -d 'Select mode to print final target to stdout'
complete -c git-smash -n "__fish_use_subcommand" -s a -l all -d 'List all revs including already published commits'
complete -c git-smash -n "__fish_use_subcommand" -s l -l local -d 'Limit the listed revs to local commits'
complete -c git-smash -n "__fish_use_subcommand" -l rebase -d 'Rebase the fixup commit into the target'
complete -c git-smash -n "__fish_use_subcommand" -l no-rebase -d 'Do not rebase the fixup commit into the target'
complete -c git-smash -n "__fish_use_subcommand" -s i -l interactive -d 'Let the user edit the list of commits before rebasing'
complete -c git-smash -n "__fish_use_subcommand" -l blame -d 'List commits acquired from blame chunks'
complete -c git-smash -n "__fish_use_subcommand" -l no-blame -d 'Do not list commits acquired from blame chunks'
complete -c git-smash -n "__fish_use_subcommand" -l files -d 'List commits acquired from history of changed files'
complete -c git-smash -n "__fish_use_subcommand" -l no-files -d 'Do not list commits acquired from history of changed files'
complete -c git-smash -n "__fish_use_subcommand" -l amend -d 'Smash staged changes and refine the log message'
complete -c git-smash -n "__fish_use_subcommand" -l reword -d 'Refine the log message ignoring all staged changes'
complete -c git-smash -n "__fish_use_subcommand" -s h -l help -d 'Print help'
complete -c git-smash -n "__fish_use_subcommand" -s V -l version -d 'Print version'
complete -c git-smash -n "__fish_use_subcommand" -f -a "completions" -d 'Generate shell completions'
complete -c git-smash -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c git-smash -n "__fish_seen_subcommand_from completions" -s h -l help -d 'Print help'
complete -c git-smash -n "__fish_seen_subcommand_from completions" -s V -l version -d 'Print version'
complete -c git-smash -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "completions" -d 'Generate shell completions'
complete -c git-smash -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
